@@ -57,15 +57,6 @@ class API: # pylint: disable=too-many-instance-attributes
             LOGGER.error("not an aoc match: %s", match_id)
             return
         players = match['players']
-        chose = None
-        if single_pov:
-            for player in players:
-                if player['url']:
-                    chose = player
-                    break
-            if not chose:
-                return
-            players = [chose]
         for player in players:
             if not player['url']:
                 continue
@@ -84,6 +75,8 @@ class API: # pylint: disable=too-many-instance-attributes
                 ladder=match.get('ladder'),
                 user_data=match['players']
             )
+            if single_pov or len(players) > 2:
+                break
 
     def add_series(self, archive_path, series=None, series_id=None):
         """Add a series via zip file."""
@@ -156,9 +149,9 @@ class API: # pylint: disable=too-many-instance-attributes
                 if guess and played:
                     if played >= datetime(2009, 9, 17):
                         platform_id = 'voobly'
-                    elif played < datetime(2009, 9, 17) and played >= datetime(2007, 6, 25):
+                    elif played < datetime(2009, 9, 17) and played >= datetime(2007, 9, 20):
                         platform_id = 'igz'
-                    elif played < datetime(2007, 6, 25) and played >= datetime(2006, 8, 1):
+                    elif played < datetime(2007, 9, 20) and played >= datetime(2006, 8, 1):
                         platform_id = 'gamepark'
                     elif played < datetime(2006, 8, 1):
                         platform_id = 'zone'
