@@ -40,6 +40,7 @@ class Person(BASE):
     aoeelo_rate = Column(Integer)
     aoeelo_rank = Column(Integer)
     esportsearnings_id = Column(Integer)
+    liquipedia = Column(String)
     earnings = Column(Float)
     first_name = Column(String)
     last_name = Column(String)
@@ -325,6 +326,7 @@ class Match(BASE):
     map_size = relationship('MapSize', foreign_keys=map_size_id)
     map_name = Column(String, index=True)
     map_tiles = Column(LargeBinary)
+    objects = Column(LargeBinary)
     event_map_id = Column(Integer, ForeignKey('event_maps.id'), index=True)
     event_map = relationship('EventMap', foreign_keys=event_map_id, backref='matches')
     rms_zr = Column(Boolean)
